@@ -14,4 +14,11 @@ class Condition(Action):
 
     async def execute(self, ctx):
         if not eval(self.data['content']):
-            return BREAK
\ No newline at end of file
+            return BREAK
+
+
+class Execute(Action):
+    CONTENT_REQUIRED = True
+
+    async def execute(self, ctx):
+        exec(ctx)
